"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    connector_definition_id: str,
    amzn_client_token: str = None,
    connectors: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a version of a connector definition which has already been defined.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        connector_definition_id(str): The ID of the connector definition.
        connectors(List, optional): A list of references to connectors in this version, with their corresponding configuration settings. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.connector_definition.version.create(
                ctx, connector_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.connector_definition.version.create connector_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="create_connector_definition_version",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "ConnectorDefinitionId": connector_definition_id,
            "Connectors": connectors,
        },
    )


async def get(
    hub,
    ctx,
    connector_definition_id: str,
    connector_definition_version_id: str,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a connector definition version, including the connectors that the version contains. Connectors are prebuilt modules that interact with local infrastructure, device protocols, AWS, and other cloud services.

    Args:
        connector_definition_id(str): The ID of the connector definition.
        connector_definition_version_id(str): The ID of the connector definition version. This value maps to the ''Version'' property of the corresponding ''VersionInformation'' object, which is returned by ''ListConnectorDefinitionVersions'' requests. If the version is the last one that was associated with a connector definition, the value also maps to the ''LatestVersion'' property of the corresponding ''DefinitionInformation'' object.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.connector_definition.version.get(
                ctx, connector_definition_id=value, connector_definition_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.connector_definition.version.get connector_definition_id=value, connector_definition_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_connector_definition_version",
        op_kwargs={
            "ConnectorDefinitionId": connector_definition_id,
            "ConnectorDefinitionVersionId": connector_definition_version_id,
            "NextToken": next_token,
        },
    )


async def list_all(
    hub,
    ctx,
    connector_definition_id: str,
    max_results: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of a connector definition, which are containers for connectors. Connectors run on the Greengrass core and contain built-in integration with local infrastructure, device protocols, AWS, and other cloud services.

    Args:
        connector_definition_id(str): The ID of the connector definition.
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.connector_definition.version.list_all(
                ctx, connector_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.connector_definition.version.list_all connector_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_connector_definition_versions",
        op_kwargs={
            "ConnectorDefinitionId": connector_definition_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "ip_address_type"


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, load_balancer_arn: str, ip_address_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Sets the type of IP addresses used by the subnets of the specified Application Load Balancer or Network Load Balancer.

    Args:
        load_balancer_arn(str): The Amazon Resource Name (ARN) of the load balancer.
        ip_address_type(str): The IP address type. The possible values are ipv4 (for IPv4 addresses) and dualstack (for IPv4 and IPv6 addresses). Internal load balancers must use ipv4. You can’t specify dualstack for a load balancer with a UDP or TCP_UDP listener.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.ip_address_type_.set(
                ctx, load_balancer_arn=value, ip_address_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.ip_address_type.set load_balancer_arn=value, ip_address_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="set_ip_address_type",
        op_kwargs={
            "LoadBalancerArn": load_balancer_arn,
            "IpAddressType": ip_address_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(
    hub, ctx, directory_id: str, user_name: str = None, password: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Disables single-sign on for a directory.

    Args:
        directory_id(str): The identifier of the directory for which to disable single-sign on.
        user_name(str, optional): The username of an alternate account to use to disable single-sign on. This is only used for AD Connector directories. This account must have privileges to remove a service principal name. If the AD Connector service account does not have privileges to remove a service principal name, you can specify an alternate account with the UserName and Password parameters. These credentials are only used to disable single sign-on and are not stored by the service. The AD Connector service account is not changed. Defaults to None.
        password(str, optional): The password of an alternate account to use to disable single-sign on. This is only used for AD Connector directories. For more information, see the UserName parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.sso.disable(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.sso.disable directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="disable_sso",
        op_kwargs={
            "DirectoryId": directory_id,
            "UserName": user_name,
            "Password": password,
        },
    )


async def enable(
    hub, ctx, directory_id: str, user_name: str = None, password: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Enables single sign-on for a directory. Single sign-on allows users in your directory to access certain AWS services from a computer joined to the directory without having to enter their credentials separately.

    Args:
        directory_id(str): The identifier of the directory for which to enable single-sign on.
        user_name(str, optional): The username of an alternate account to use to enable single-sign on. This is only used for AD Connector directories. This account must have privileges to add a service principal name. If the AD Connector service account does not have privileges to add a service principal name, you can specify an alternate account with the UserName and Password parameters. These credentials are only used to enable single sign-on and are not stored by the service. The AD Connector service account is not changed. Defaults to None.
        password(str, optional): The password of an alternate account to use to enable single-sign on. This is only used for AD Connector directories. For more information, see the UserName parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.sso.enable(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.sso.enable directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="enable_sso",
        op_kwargs={
            "DirectoryId": directory_id,
            "UserName": user_name,
            "Password": password,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def accept(
    hub, ctx, studio_id: str, client_token: str = None, eula_ids: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Accept EULAs.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        eula_ids(List, optional): The EULA ID. Defaults to None.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.eulas.accept(ctx, studio_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.eulas.accept studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="accept_eulas",
        op_kwargs={
            "clientToken": client_token,
            "eulaIds": eula_ids,
            "studioId": studio_id,
        },
    )


async def list_(hub, ctx, eula_ids: List = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List Eulas.

    Args:
        eula_ids(List, optional): A collection of EULA IDs. Defaults to None.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.eulas.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.eulas.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="list_eulas",
        op_kwargs={"eulaIds": eula_ids, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    client_request_token: str,
    network_id: str,
    member_id: str,
    actions: Dict,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a proposal for a change to the network that other members of the network can vote on, for example, a proposal to add a new member to the network. Any member can create a proposal. Applies only to Hyperledger Fabric.

    Args:
        client_request_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than one time. This identifier is required only if you make a service request directly using an HTTP client. It is generated automatically if you use an AWS SDK or the AWS CLI.
        network_id(str):  The unique identifier of the network for which the proposal is made.
        member_id(str): The unique identifier of the member that is creating the proposal. This identifier is especially useful for identifying the member making the proposal when multiple members exist in a single AWS account.
        actions(Dict): The type of actions proposed, such as inviting a member or removing a member. The types of Actions in a proposal are mutually exclusive. For example, a proposal with Invitations actions cannot also contain Removals actions.
        description(str, optional): A description for the proposal that is visible to voting members, for example, "Proposal to add Example Corp. as member.". Defaults to None.
        tags(Dict, optional): Tags to assign to the proposal. Each tag consists of a key and optional value. When specifying tags during creation, you can specify multiple key-value pairs in a single request, with an overall maximum of 50 tags added to each resource. If the proposal is for a network invitation, the invitation inherits the tags added to the proposal. For more information about tags, see Tagging Resources in the Amazon Managed Blockchain Ethereum Developer Guide, or Tagging Resources in the Amazon Managed Blockchain Hyperledger Fabric Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.proposal.init.create(
                ctx, client_request_token=value, network_id=value, member_id=value, actions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.proposal.init.create client_request_token=value, network_id=value, member_id=value, actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="create_proposal",
        op_kwargs={
            "ClientRequestToken": client_request_token,
            "NetworkId": network_id,
            "MemberId": member_id,
            "Actions": actions,
            "Description": description,
            "Tags": tags,
        },
    )


async def get(hub, ctx, network_id: str, proposal_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed information about a proposal. Applies only to Hyperledger Fabric.

    Args:
        network_id(str): The unique identifier of the network for which the proposal is made.
        proposal_id(str): The unique identifier of the proposal.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.proposal.init.get(
                ctx, network_id=value, proposal_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.proposal.init.get network_id=value, proposal_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="get_proposal",
        op_kwargs={"NetworkId": network_id, "ProposalId": proposal_id},
    )


async def list_all(
    hub, ctx, network_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of proposals for the network. Applies only to Hyperledger Fabric.

    Args:
        network_id(str):  The unique identifier of the network. .
        max_results(int, optional):  The maximum number of proposals to return. . Defaults to None.
        next_token(str, optional):  The pagination token that indicates the next set of results to retrieve. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.proposal.init.list_all(ctx, network_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.proposal.init.list_all network_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="list_proposals",
        op_kwargs={
            "NetworkId": network_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(hub, ctx, old_name: str, new_name: str) -> None:
    r"""
    **Autogenerated function**

    Renames a repository. The repository name must be unique across the calling AWS account. Repository names are limited to 100 alphanumeric, dash, and underscore characters, and cannot include certain characters. The suffix .git is prohibited. For more information about the limits on repository names, see Limits in the AWS CodeCommit User Guide.

    Args:
        old_name(str): The current name of the repository.
        new_name(str): The new name for the repository.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.repository.name.update(
                ctx, old_name=value, new_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.repository.name.update old_name=value, new_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="update_repository_name",
        op_kwargs={"oldName": old_name, "newName": new_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, create_recommender_configuration: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Pinpoint configuration for a recommender model.

    Args:
        create_recommender_configuration(Dict): Specifies Amazon Pinpoint configuration settings for retrieving and processing recommendation data from a recommender model.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.recommender_configuration.create(
                ctx, create_recommender_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.recommender_configuration.create create_recommender_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="create_recommender_configuration",
        op_kwargs={"CreateRecommenderConfiguration": create_recommender_configuration},
    )


async def delete(hub, ctx, recommender_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Amazon Pinpoint configuration for a recommender model.

    Args:
        recommender_id(str): The unique identifier for the recommender model configuration. This identifier is displayed as the Recommender ID on the Amazon Pinpoint console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.recommender_configuration.delete(
                ctx, recommender_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.recommender_configuration.delete recommender_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="delete_recommender_configuration",
        op_kwargs={"RecommenderId": recommender_id},
    )


async def get(hub, ctx, recommender_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about an Amazon Pinpoint configuration for a recommender model.

    Args:
        recommender_id(str): The unique identifier for the recommender model configuration. This identifier is displayed as the Recommender ID on the Amazon Pinpoint console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.recommender_configuration.get(
                ctx, recommender_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.recommender_configuration.get recommender_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_recommender_configuration",
        op_kwargs={"RecommenderId": recommender_id},
    )


async def get_all(hub, ctx, page_size: str = None, token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about all the recommender model configurations that are associated with your Amazon Pinpoint account.

    Args:
        page_size(str, optional): The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics. Defaults to None.
        token(str, optional): The NextToken string that specifies which page of results to return in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.recommender_configuration.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.recommender_configuration.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_recommender_configurations",
        op_kwargs={"PageSize": page_size, "Token": token},
    )


async def update(
    hub, ctx, recommender_id: str, update_recommender_configuration: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an Amazon Pinpoint configuration for a recommender model.

    Args:
        recommender_id(str): The unique identifier for the recommender model configuration. This identifier is displayed as the Recommender ID on the Amazon Pinpoint console.
        update_recommender_configuration(Dict): Specifies Amazon Pinpoint configuration settings for retrieving and processing recommendation data from a recommender model.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.recommender_configuration.update(
                ctx, recommender_id=value, update_recommender_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.recommender_configuration.update recommender_id=value, update_recommender_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="update_recommender_configuration",
        op_kwargs={
            "RecommenderId": recommender_id,
            "UpdateRecommenderConfiguration": update_recommender_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    db_cluster_identifier: str,
    backtrack_identifier: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about backtracks for a DB cluster. For more information on Amazon Aurora, see  What Is Amazon Aurora? in the Amazon Aurora User Guide.   This action only applies to Aurora MySQL DB clusters.

    Args:
        db_cluster_identifier(str): The DB cluster identifier of the DB cluster to be described. This parameter is stored as a lowercase string. Constraints:   Must contain from 1 to 63 alphanumeric characters or hyphens.   First character must be a letter.   Can't end with a hyphen or contain two consecutive hyphens.   Example: my-cluster1 .
        backtrack_identifier(str, optional): If specified, this value is the backtrack identifier of the backtrack to be described. Constraints:   Must contain a valid universally unique identifier (UUID). For more information about UUIDs, see A Universally Unique Identifier (UUID) URN Namespace.   Example: 123e4567-e89b-12d3-a456-426655440000 . Defaults to None.
        filters(List, optional): A filter that specifies one or more DB clusters to describe. Supported filters include the following:    db-cluster-backtrack-id - Accepts backtrack identifiers. The results list includes information about only the backtracks identified by these identifiers.    db-cluster-backtrack-status - Accepts any of the following backtrack status values:    applying     completed     failed     pending    The results list includes information about only the backtracks identified by these values.  . Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeDBClusterBacktracks request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.cluster.backtrack.describe_all(
                ctx, db_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.cluster.backtrack.describe_all db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_db_cluster_backtracks",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "BacktrackIdentifier": backtrack_identifier,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, application_name: str, resource_lifecycle_config: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies lifecycle settings for an application.

    Args:
        application_name(str): The name of the application.
        resource_lifecycle_config(Dict): The lifecycle configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.application.resource_lifecycle.update(
                ctx, application_name=value, resource_lifecycle_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.application.resource_lifecycle.update application_name=value, resource_lifecycle_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="update_application_resource_lifecycle",
        op_kwargs={
            "ApplicationName": application_name,
            "ResourceLifecycleConfig": resource_lifecycle_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    slot_name: str,
    slot_type_id: str,
    value_elicitation_setting: Dict,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    intent_id: str,
    description: str = None,
    obfuscation_setting: Dict = None,
    multiple_values_setting: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a slot in an intent. A slot is a variable needed to fulfill an intent. For example, an OrderPizza intent might need slots for size, crust, and number of pizzas. For each slot, you define one or more utterances that Amazon Lex uses to elicit a response from the user.

    Args:
        slot_name(str): The name of the slot. Slot names must be unique within the bot that contains the slot.
        description(str, optional): A description of the slot. Use this to help identify the slot in lists. Defaults to None.
        slot_type_id(str): The unique identifier for the slot type associated with this slot. The slot type determines the values that can be entered into the slot.
        value_elicitation_setting(Dict): Specifies prompts that Amazon Lex sends to the user to elicit a response that provides the value for the slot. .
        obfuscation_setting(Dict, optional): Determines how slot values are used in Amazon CloudWatch logs. If the value of the obfuscationSetting parameter is DefaultObfuscation, slot values are obfuscated in the log output. If the value is None, the actual value is present in the log output. The default is to obfuscate values in the CloudWatch logs. Defaults to None.
        bot_id(str): The identifier of the bot associated with the slot.
        bot_version(str): The version of the bot associated with the slot.
        locale_id(str): The identifier of the language and locale that the slot will be used in. The string must match one of the supported locales. All of the bots, intents, slot types used by the slot must have the same locale. For more information, see Supported languages.
        intent_id(str): The identifier of the intent that contains the slot.
        multiple_values_setting(Dict, optional): Indicates whether the slot returns multiple values in one response. Multi-value slots are only available in the en-US locale. If you set this value to true in any other locale, Amazon Lex throws a ValidationException.  If the multipleValuesSetting is not set, the default value is false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.slot.init.create(
                ctx,
                slot_name=value,
                slot_type_id=value,
                value_elicitation_setting=value,
                bot_id=value,
                bot_version=value,
                locale_id=value,
                intent_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.slot.init.create slot_name=value, slot_type_id=value, value_elicitation_setting=value, bot_id=value, bot_version=value, locale_id=value, intent_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="create_slot",
        op_kwargs={
            "slotName": slot_name,
            "description": description,
            "slotTypeId": slot_type_id,
            "valueElicitationSetting": value_elicitation_setting,
            "obfuscationSetting": obfuscation_setting,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
            "intentId": intent_id,
            "multipleValuesSetting": multiple_values_setting,
        },
    )


async def delete(
    hub,
    ctx,
    slot_id: str,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    intent_id: str,
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified slot from an intent.

    Args:
        slot_id(str): The identifier of the slot to delete. .
        bot_id(str): The identifier of the bot associated with the slot to delete.
        bot_version(str): The version of the bot associated with the slot to delete.
        locale_id(str): The identifier of the language and locale that the slot will be deleted from. The string must match one of the supported locales. For more information, see Supported languages.
        intent_id(str): The identifier of the intent associated with the slot.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.slot.init.delete(
                ctx,
                slot_id=value,
                bot_id=value,
                bot_version=value,
                locale_id=value,
                intent_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.slot.init.delete slot_id=value, bot_id=value, bot_version=value, locale_id=value, intent_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="delete_slot",
        op_kwargs={
            "slotId": slot_id,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
            "intentId": intent_id,
        },
    )


async def describe(
    hub,
    ctx,
    slot_id: str,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    intent_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets metadata information about a slot.

    Args:
        slot_id(str): The unique identifier for the slot.
        bot_id(str): The identifier of the bot associated with the slot.
        bot_version(str): The version of the bot associated with the slot.
        locale_id(str): The identifier of the language and locale of the slot to describe. The string must match one of the supported locales. For more information, see Supported languages.
        intent_id(str): The identifier of the intent that contains the slot.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.slot.init.describe(
                ctx,
                slot_id=value,
                bot_id=value,
                bot_version=value,
                locale_id=value,
                intent_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.slot.init.describe slot_id=value, bot_id=value, bot_version=value, locale_id=value, intent_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="describe_slot",
        op_kwargs={
            "slotId": slot_id,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
            "intentId": intent_id,
        },
    )


async def list_all(
    hub,
    ctx,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    intent_id: str,
    sort_by: Dict = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of slots that match the specified criteria.

    Args:
        bot_id(str): The identifier of the bot that contains the slot.
        bot_version(str): The version of the bot that contains the slot.
        locale_id(str): The identifier of the language and locale of the slots to list. The string must match one of the supported locales. For more information, see Supported languages.
        intent_id(str): The unique identifier of the intent that contains the slot.
        sort_by(Dict, optional): Determines the sort order for the response from the ListSlots operation. You can choose to sort by the slot name or last updated date in either ascending or descending order. Defaults to None.
        filters(List, optional): Provides the specification of a filter used to limit the slots in the response to only those that match the filter specification. You can only specify one filter and only one string to filter on. Defaults to None.
        max_results(int, optional): The maximum number of slots to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned. Defaults to None.
        next_token(str, optional): If the response from the ListSlots operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.slot.init.list_all(
                ctx, bot_id=value, bot_version=value, locale_id=value, intent_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.slot.init.list_all bot_id=value, bot_version=value, locale_id=value, intent_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="list_slots",
        op_kwargs={
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
            "intentId": intent_id,
            "sortBy": sort_by,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    slot_id: str,
    slot_name: str,
    slot_type_id: str,
    value_elicitation_setting: Dict,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    intent_id: str,
    description: str = None,
    obfuscation_setting: Dict = None,
    multiple_values_setting: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the settings for a slot.

    Args:
        slot_id(str): The unique identifier for the slot to update.
        slot_name(str): The new name for the slot.
        description(str, optional): The new description for the slot. Defaults to None.
        slot_type_id(str): The unique identifier of the new slot type to associate with this slot. .
        value_elicitation_setting(Dict): A new set of prompts that Amazon Lex sends to the user to elicit a response the provides a value for the slot.
        obfuscation_setting(Dict, optional): New settings that determine how slot values are formatted in Amazon CloudWatch logs. . Defaults to None.
        bot_id(str): The unique identifier of the bot that contains the slot.
        bot_version(str): The version of the bot that contains the slot. Must always be DRAFT.
        locale_id(str): The identifier of the language and locale that contains the slot. The string must match one of the supported locales. For more information, see Supported languages.
        intent_id(str): The identifier of the intent that contains the slot.
        multiple_values_setting(Dict, optional): Determines whether the slot accepts multiple values in one response. Multiple value slots are only available in the en-US locale. If you set this value to true in any other locale, Amazon Lex throws a ValidationException. If the multipleValuesSetting is not set, the default value is false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.slot.init.update(
                ctx,
                slot_id=value,
                slot_name=value,
                slot_type_id=value,
                value_elicitation_setting=value,
                bot_id=value,
                bot_version=value,
                locale_id=value,
                intent_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.slot.init.update slot_id=value, slot_name=value, slot_type_id=value, value_elicitation_setting=value, bot_id=value, bot_version=value, locale_id=value, intent_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="update_slot",
        op_kwargs={
            "slotId": slot_id,
            "slotName": slot_name,
            "description": description,
            "slotTypeId": slot_type_id,
            "valueElicitationSetting": value_elicitation_setting,
            "obfuscationSetting": obfuscation_setting,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
            "intentId": intent_id,
            "multipleValuesSetting": multiple_values_setting,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    creation_token: str,
    performance_mode: str = None,
    encrypted: bool = None,
    kms_key_id: str = None,
    throughput_mode: str = None,
    provisioned_throughput_in_mibps: float = None,
    availability_zone_name: str = None,
    backup: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new, empty file system. The operation requires a creation token in the request that Amazon EFS uses to ensure idempotent creation (calling the operation with same creation token has no effect). If a file system does not currently exist that is owned by the caller's AWS account with the specified creation token, this operation does the following:   Creates a new, empty file system. The file system will have an Amazon EFS assigned ID, and an initial lifecycle state creating.   Returns with the description of the created file system.   Otherwise, this operation returns a FileSystemAlreadyExists error with the ID of the existing file system.  For basic use cases, you can use a randomly generated UUID for the creation token.   The idempotent operation allows you to retry a CreateFileSystem call without risk of creating an extra file system. This can happen when an initial call fails in a way that leaves it uncertain whether or not a file system was actually created. An example might be that a transport level timeout occurred or your connection was reset. As long as you use the same creation token, if the initial call had succeeded in creating a file system, the client can learn of its existence from the FileSystemAlreadyExists error. For more information, see Creating a file system in the Amazon EFS User Guide.  The CreateFileSystem call returns while the file system's lifecycle state is still creating. You can check the file system creation status by calling the DescribeFileSystems operation, which among other things returns the file system state.  This operation accepts an optional PerformanceMode parameter that you choose for your file system. We recommend generalPurpose performance mode for most file systems. File systems using the maxIO performance mode can scale to higher levels of aggregate throughput and operations per second with a tradeoff of slightly higher latencies for most file operations. The performance mode can't be changed after the file system has been created. For more information, see Amazon EFS performance modes. You can set the throughput mode for the file system using the ThroughputMode parameter. After the file system is fully created, Amazon EFS sets its lifecycle state to available, at which point you can create one or more mount targets for the file system in your VPC. For more information, see CreateMountTarget. You mount your Amazon EFS file system on an EC2 instances in your VPC by using the mount target. For more information, see Amazon EFS: How it Works.   This operation requires permissions for the elasticfilesystem:CreateFileSystem action.

    Args:
        creation_token(str): A string of up to 64 ASCII characters. Amazon EFS uses this to ensure idempotent creation.
        performance_mode(str, optional): The performance mode of the file system. We recommend generalPurpose performance mode for most file systems. File systems using the maxIO performance mode can scale to higher levels of aggregate throughput and operations per second with a tradeoff of slightly higher latencies for most file operations. The performance mode can't be changed after the file system has been created.  The maxIO mode is not supported on file systems using One Zone storage classes. . Defaults to None.
        encrypted(bool, optional): A Boolean value that, if true, creates an encrypted file system. When creating an encrypted file system, you have the option of specifying CreateFileSystemRequest$KmsKeyId for an existing AWS Key Management Service (AWS KMS) customer master key (CMK). If you don't specify a CMK, then the default CMK for Amazon EFS, /aws/elasticfilesystem, is used to protect the encrypted file system. . Defaults to None.
        kms_key_id(str, optional): The ID of the AWS KMS CMK that you want to use to protect the encrypted file system. This parameter is only required if you want to use a non-default KMS key. If this parameter is not specified, the default CMK for Amazon EFS is used. This ID can be in one of the following formats:   Key ID - A unique identifier of the key, for example 1234abcd-12ab-34cd-56ef-1234567890ab.   ARN - An Amazon Resource Name (ARN) for the key, for example arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab.   Key alias - A previously created display name for a key, for example alias/projectKey1.   Key alias ARN - An ARN for a key alias, for example arn:aws:kms:us-west-2:444455556666:alias/projectKey1.   If KmsKeyId is specified, the CreateFileSystemRequest$Encrypted parameter must be set to true.  EFS accepts only symmetric KMS keys. You cannot use asymmetric KMS keys with EFS file systems. . Defaults to None.
        throughput_mode(str, optional): Specifies the throughput mode for the file system, either bursting or provisioned. If you set ThroughputMode to provisioned, you must also set a value for ProvisionedThroughputInMibps. After you create the file system, you can decrease your file system's throughput in Provisioned Throughput mode or change between the throughput modes, as long as it’s been more than 24 hours since the last decrease or throughput mode change. For more information, see Specifying throughput with provisioned mode in the Amazon EFS User Guide.  Default is bursting. Defaults to None.
        provisioned_throughput_in_mibps(float, optional): The throughput, measured in MiB/s, that you want to provision for a file system that you're creating. Valid values are 1-1024. Required if ThroughputMode is set to provisioned. The upper limit for throughput is 1024 MiB/s. To increase this limit, contact AWS Support. For more information, see Amazon EFS quotas that you can increase in the Amazon EFS User Guide. Defaults to None.
        availability_zone_name(str, optional): Used to create a file system that uses One Zone storage classes. It specifies the AWS Availability Zone in which to create the file system. Use the format us-east-1a to specify the Availability Zone. For more information about One Zone storage classes, see Using EFS storage classes in the Amazon EFS User Guide.  One Zone storage classes are not available in all Availability Zones in AWS Regions where Amazon EFS is available. . Defaults to None.
        backup(bool, optional): Specifies whether automatic backups are enabled on the file system that you are creating. Set the value to true to enable automatic backups. If you are creating a file system that uses One Zone storage classes, automatic backups are enabled by default. For more information, see Automatic backups in the Amazon EFS User Guide. Default is false. However, if you specify an AvailabilityZoneName, the default is true.  AWS Backup is not available in all AWS Regions where Amazon EFS is available. . Defaults to None.
        tags(List, optional): A value that specifies to create one or more tags associated with the file system. Each tag is a user-defined key-value pair. Name your file system on creation by including a "Key":"Name","Value":"{value}" key-value pair. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.file_system.init.create(ctx, creation_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.file_system.init.create creation_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="create_file_system",
        op_kwargs={
            "CreationToken": creation_token,
            "PerformanceMode": performance_mode,
            "Encrypted": encrypted,
            "KmsKeyId": kms_key_id,
            "ThroughputMode": throughput_mode,
            "ProvisionedThroughputInMibps": provisioned_throughput_in_mibps,
            "AvailabilityZoneName": availability_zone_name,
            "Backup": backup,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, file_system_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a file system, permanently severing access to its contents. Upon return, the file system no longer exists and you can't access any contents of the deleted file system.  You can't delete a file system that is in use. That is, if the file system has any mount targets, you must first delete them. For more information, see DescribeMountTargets and DeleteMountTarget.   The DeleteFileSystem call returns while the file system state is still deleting. You can check the file system deletion status by calling the DescribeFileSystems operation, which returns a list of file systems in your account. If you pass file system ID or creation token for the deleted file system, the DescribeFileSystems returns a 404 FileSystemNotFound error.  This operation requires permissions for the elasticfilesystem:DeleteFileSystem action.

    Args:
        file_system_id(str): The ID of the file system you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.file_system.init.delete(ctx, file_system_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.file_system.init.delete file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="delete_file_system",
        op_kwargs={"FileSystemId": file_system_id},
    )


async def describe_all(
    hub,
    ctx,
    max_items: int = None,
    marker: str = None,
    creation_token: str = None,
    file_system_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the description of a specific Amazon EFS file system if either the file system CreationToken or the FileSystemId is provided. Otherwise, it returns descriptions of all file systems owned by the caller's AWS account in the AWS Region of the endpoint that you're calling. When retrieving all file system descriptions, you can optionally specify the MaxItems parameter to limit the number of descriptions in a response. Currently, this number is automatically set to 10. If more file system descriptions remain, Amazon EFS returns a NextMarker, an opaque token, in the response. In this case, you should send a subsequent request with the Marker request parameter set to the value of NextMarker.  To retrieve a list of your file system descriptions, this operation is used in an iterative process, where DescribeFileSystems is called first without the Marker and then the operation continues to call it with the Marker parameter set to the value of the NextMarker from the previous response until the response has no NextMarker.   The order of file systems returned in the response of one DescribeFileSystems call and the order of file systems returned across the responses of a multi-call iteration is unspecified.   This operation requires permissions for the elasticfilesystem:DescribeFileSystems action.

    Args:
        max_items(int, optional): (Optional) Specifies the maximum number of file systems to return in the response (integer). This number is automatically set to 100. The response is paginated at 100 per page if you have more than 100 file systems. . Defaults to None.
        marker(str, optional): (Optional) Opaque pagination token returned from a previous DescribeFileSystems operation (String). If present, specifies to continue the list from where the returning call had left off. . Defaults to None.
        creation_token(str, optional): (Optional) Restricts the list to the file system with this creation token (String). You specify a creation token when you create an Amazon EFS file system. Defaults to None.
        file_system_id(str, optional): (Optional) ID of the file system whose description you want to retrieve (String). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.file_system.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.file_system.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="describe_file_systems",
        op_kwargs={
            "MaxItems": max_items,
            "Marker": marker,
            "CreationToken": creation_token,
            "FileSystemId": file_system_id,
        },
    )


async def update(
    hub,
    ctx,
    file_system_id: str,
    throughput_mode: str = None,
    provisioned_throughput_in_mibps: float = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the throughput mode or the amount of provisioned throughput of an existing file system.

    Args:
        file_system_id(str): The ID of the file system that you want to update.
        throughput_mode(str, optional): (Optional) Updates the file system's throughput mode. If you're not updating your throughput mode, you don't need to provide this value in your request. If you are changing the ThroughputMode to provisioned, you must also set a value for ProvisionedThroughputInMibps. Defaults to None.
        provisioned_throughput_in_mibps(float, optional): (Optional) Sets the amount of provisioned throughput, in MiB/s, for the file system. Valid values are 1-1024. If you are changing the throughput mode to provisioned, you must also provide the amount of provisioned throughput. Required if ThroughputMode is changed to provisioned on update. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.file_system.init.update(ctx, file_system_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.file_system.init.update file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="update_file_system",
        op_kwargs={
            "FileSystemId": file_system_id,
            "ThroughputMode": throughput_mode,
            "ProvisionedThroughputInMibps": provisioned_throughput_in_mibps,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, permission_arn: str, permission_version: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the contents of an AWS RAM permission in JSON format.

    Args:
        permission_arn(str): The ARN of the permission.
        permission_version(int, optional): The identifier for the version of the permission. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.permission.get(ctx, permission_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.permission.get permission_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="get_permission",
        op_kwargs={
            "permissionArn": permission_arn,
            "permissionVersion": permission_version,
        },
    )


async def list_all(
    hub, ctx, resource_type: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the AWS RAM permissions.

    Args:
        resource_type(str, optional): Specifies the resource type for which to list permissions. For example, to list only permissions that apply to EC2 subnets, specify ec2:Subnet. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.permission.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.permission.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="list_permissions",
        op_kwargs={
            "resourceType": resource_type,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, service_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Initiate a manual deployment of the latest commit in a source code repository or the latest image in a source image repository to an AWS App Runner service. For a source code repository, App Runner retrieves the commit and builds a Docker image. For a source image repository, App Runner retrieves the latest Docker image. In both cases, App Runner then deploys the new image to your service and starts a new container instance. This is an asynchronous operation. On a successful call, you can use the returned OperationId and the ListOperations call to track the operation's progress.

    Args:
        service_arn(str): The Amazon Resource Name (ARN) of the App Runner service that you want to manually deploy to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.deployment.start(ctx, service_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.deployment.start service_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="start_deployment",
        op_kwargs={"ServiceArn": service_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, max_results: int = None, next_token: str = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists resources managed using Systems Manager inventory.

    Args:
        max_results(int, optional): Maximum number of results to return in a single call. Defaults to None.
        next_token(str, optional): Token for the next set of results. Defaults to None.
        filters(List, optional): Filters to scope the results. The following filters and logical operators are supported:    account_id - The ID of the AWS account that owns the resource. Logical operators are EQUALS | NOT_EQUALS.    application_name - The name of the application. Logical operators are EQUALS | BEGINS_WITH.    license_included - The type of license included. Logical operators are EQUALS | NOT_EQUALS. Possible values are sql-server-enterprise | sql-server-standard | sql-server-web | windows-server-datacenter.    platform - The platform of the resource. Logical operators are EQUALS | BEGINS_WITH.    resource_id - The ID of the resource. Logical operators are EQUALS | NOT_EQUALS.    tag:<key> - The key/value combination of a tag assigned to the resource. Logical operators are EQUALS (single account) or EQUALS | NOT_EQUALS (cross account).  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.resource.inventory.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.resource.inventory.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="list_resource_inventory",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )



# https://pop.readthedocs.io/en/latest/tutorial/quickstart.html#adding-configuration-data
# In this dictionary goes all the immutable values you want to show up under hub.OPT.idem_aws_auto
CONFIG = {
    "config": {
        "default": None,
        "help": "Load extra options from a configuration file onto hub.OPT.idem_aws_auto",
    }
}

# The selected subcommand for your cli tool will show up under hub.SUBPARSER
# The value for a subcommand is a dictionary that will be passed as kwargs to argparse.ArgumentParser.add_subparsers
SUBCOMMANDS = {
    # "my_sub_command": {}
}

# Include keys from the CONFIG dictionary that you want to expose on the cli
# The values for these keys are a dictionaries that will be passed as kwargs to argparse.ArgumentParser.add_option
CLI_CONFIG = {
    "config": {"options": ["-c"]},
    # "my_option1": {"subcommands": ["A list of subcommands that exclusively extend this option"]},
    # This option will be available under all subcommands and the root command
    # "my_option2": {"subcommands": ["_global_"]},
}

# These are the namespaces that your project extends
# The hub will extend these keys with the modules listed in the values
DYNE = {"exec": ["exec"]}



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Assigns a set of tags to an Amazon Cognito user pool. A tag is a label that you can use to categorize and manage user pools in different ways, such as by purpose, owner, environment, or other criteria. Each tag consists of a key and value, both of which you define. A key is a general category for more specific values. For example, if you have two versions of a user pool, one for testing and another for production, you might assign an Environment tag key to both user pools. The value of this key might be Test for one user pool and Production for the other. Tags are useful for cost tracking and access control. You can activate your tags so that they appear on the Billing and Cost Management console, where you can track the costs associated with your user pools. In an IAM policy, you can constrain permissions for user pools based on specific tags or tag values. You can use this action up to 5 times per second, per account. A user pool can have as many as 50 tags.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the user pool to assign the tags to.
        tags(Dict): The tags to assign to the user pool.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.resource.init.tag(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.resource.init.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified tags from an Amazon Cognito user pool. You can use this action up to 5 times per second, per account

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the user pool that the tags are assigned to.
        tag_keys(List): The keys of the tags to remove from the user pool.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.resource.init.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.resource.init.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    time_period: Dict,
    metric: str,
    granularity: str,
    filter_: Dict = None,
    prediction_interval_level: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a forecast for how much Amazon Web Services predicts that you will use over the forecast time period that you select, based on your past usage.

    Args:
        time_period(Dict): The start and end dates of the period that you want to retrieve usage forecast for. The start date is inclusive, but the end date is exclusive. For example, if start is 2017-01-01 and end is 2017-05-01, then the cost and usage data is retrieved from 2017-01-01 up to and including 2017-04-30 but not including 2017-05-01. The start date must be equal to or later than the current date to avoid a validation error.
        metric(str): Which metric Cost Explorer uses to create your forecast. Valid values for a GetUsageForecast call are the following:   USAGE_QUANTITY   NORMALIZED_USAGE_AMOUNT  .
        granularity(str): How granular you want the forecast to be. You can get 3 months of DAILY forecasts or 12 months of MONTHLY forecasts. The GetUsageForecast operation supports only DAILY and MONTHLY granularities.
        filter_(Dict, optional): The filters that you want to use to filter your forecast. The GetUsageForecast API supports filtering by the following dimensions:    AZ     INSTANCE_TYPE     LINKED_ACCOUNT     LINKED_ACCOUNT_NAME     OPERATION     PURCHASE_TYPE     REGION     SERVICE     USAGE_TYPE     USAGE_TYPE_GROUP     RECORD_TYPE     OPERATING_SYSTEM     TENANCY     SCOPE     PLATFORM     SUBSCRIPTION_ID     LEGAL_ENTITY_NAME     DEPLOYMENT_OPTION     DATABASE_ENGINE     INSTANCE_TYPE_FAMILY     BILLING_ENTITY     RESERVATION_ID     SAVINGS_PLAN_ARN   . Defaults to None.
        prediction_interval_level(int, optional): Cost Explorer always returns the mean forecast as a single point. You can request a prediction interval around the mean by specifying a confidence level. The higher the confidence level, the more confident Cost Explorer is about the actual value falling in the prediction interval. Higher confidence levels result in wider prediction intervals. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.usage_forecast.get(
                ctx, time_period=value, metric=value, granularity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.usage_forecast.get time_period=value, metric=value, granularity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_usage_forecast",
        op_kwargs={
            "TimePeriod": time_period,
            "Metric": metric,
            "Granularity": granularity,
            "Filter": filter_,
            "PredictionIntervalLevel": prediction_interval_level,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, instance_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the configuration data of the specified instance. You can use this data to create a launch template.  This action calls on other describe actions to get instance information. Depending on your instance configuration, you may need to allow the following actions in your IAM policy: DescribeSpotInstanceRequests, DescribeInstanceCreditSpecifications, DescribeVolumes, DescribeInstanceAttribute, and DescribeElasticGpus. Or, you can allow describe* depending on your instance requirements.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_id(str): The ID of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.launch_template.data.get(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.launch_template.data.get instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_launch_template_data",
        op_kwargs={"DryRun": dry_run, "InstanceId": instance_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, principal_id: str, studio_id: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Delete a user from studio membership.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        principal_id(str): The principal ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.member.delete(
                ctx, principal_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.member.delete principal_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="delete_studio_member",
        op_kwargs={
            "clientToken": client_token,
            "principalId": principal_id,
            "studioId": studio_id,
        },
    )


async def get(hub, ctx, principal_id: str, studio_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get a user's membership in a studio.

    Args:
        principal_id(str): The principal ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.member.get(
                ctx, principal_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.member.get principal_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="get_studio_member",
        op_kwargs={"principalId": principal_id, "studioId": studio_id},
    )


async def list_all(
    hub, ctx, studio_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Get all users in a given studio membership.

    Args:
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.member.list_all(ctx, studio_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.member.list_all studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="list_studio_members",
        op_kwargs={
            "maxResults": max_results,
            "nextToken": next_token,
            "studioId": studio_id,
        },
    )


async def put_multiple(
    hub,
    ctx,
    identity_store_id: str,
    members: List,
    studio_id: str,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Add/update users with given persona to studio membership.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        identity_store_id(str): The ID of the identity store.
        members(List): A list of members.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.member.put_multiple(
                ctx, identity_store_id=value, members=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.member.put_multiple identity_store_id=value, members=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="put_studio_members",
        op_kwargs={
            "clientToken": client_token,
            "identityStoreId": identity_store_id,
            "members": members,
            "studioId": studio_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(hub, ctx, key_id: str, description: str) -> None:
    r"""
    **Autogenerated function**

    Updates the description of a customer master key (CMK). To see the description of a CMK, use DescribeKey.  The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.   Required permissions: kms:UpdateKeyDescription (key policy)  Related operations     CreateKey     DescribeKey

    Args:
        key_id(str): Updates the description of the specified customer master key (CMK). Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        description(str): New description for the CMK.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.description.update(ctx, key_id=value, description=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.description.update key_id=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="update_key_description",
        op_kwargs={"KeyId": key_id, "Description": description},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the current status and future status of all offerings purchased by an AWS account. The response indicates how many offerings are currently available and the offerings that will be available in the next period. The API returns a NotEligible error if the user is not permitted to invoke the operation. If you must be able to invoke this operation, contact aws-devicefarm-support@amazon.com.

    Args:
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.offering.status.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.offering.status.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="get_offering_status",
        op_kwargs={"nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    outpost_id: str,
    subnet_id: str,
    security_group_id: str,
    access_type: str = None,
    customer_owned_ipv4_pool: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Amazon S3 on Outposts Access Points simplify managing data access at scale for shared datasets in S3 on Outposts. S3 on Outposts uses endpoints to connect to Outposts buckets so that you can perform actions within your virtual private cloud (VPC). For more information, see  Accessing S3 on Outposts using VPC only access points. This action creates an endpoint and associates it with the specified Outposts.  It can take up to 5 minutes for this action to complete.   Related actions include:    DeleteEndpoint     ListEndpoints

    Args:
        outpost_id(str): The ID of the AWS Outposts. .
        subnet_id(str): The ID of the subnet in the selected VPC. The endpoint subnet must belong to the Outpost that has the Amazon S3 on Outposts provisioned.
        security_group_id(str): The ID of the security group to use with the endpoint.
        access_type(str, optional): The type of access for the on-premise network connectivity for the Outpost endpoint. To access the endpoint from an on-premises network, you must specify the access type and provide the customer owned IPv4 pool. Defaults to None.
        customer_owned_ipv4_pool(str, optional): The ID of the customer-owned IPv4 pool for the endpoint. IP addresses will be allocated from this pool for the endpoint. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3outpost_endpoint.create(
                ctx, outpost_id=value, subnet_id=value, security_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3outpost_endpoint.create outpost_id=value, subnet_id=value, security_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3outposts",
        operation="create_endpoint",
        op_kwargs={
            "OutpostId": outpost_id,
            "SubnetId": subnet_id,
            "SecurityGroupId": security_group_id,
            "AccessType": access_type,
            "CustomerOwnedIpv4Pool": customer_owned_ipv4_pool,
        },
    )


async def delete(hub, ctx, endpoint_id: str, outpost_id: str) -> None:
    r"""
    **Autogenerated function**

    Amazon S3 on Outposts Access Points simplify managing data access at scale for shared datasets in S3 on Outposts. S3 on Outposts uses endpoints to connect to Outposts buckets so that you can perform actions within your virtual private cloud (VPC). For more information, see  Accessing S3 on Outposts using VPC only access points. This action deletes an endpoint.  It can take up to 5 minutes for this action to complete.   Related actions include:    CreateEndpoint     ListEndpoints

    Args:
        endpoint_id(str): The ID of the endpoint.
        outpost_id(str): The ID of the AWS Outposts. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3outpost_endpoint.delete(
                ctx, endpoint_id=value, outpost_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3outpost_endpoint.delete endpoint_id=value, outpost_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3outposts",
        operation="delete_endpoint",
        op_kwargs={"EndpointId": endpoint_id, "OutpostId": outpost_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Amazon S3 on Outposts Access Points simplify managing data access at scale for shared datasets in S3 on Outposts. S3 on Outposts uses endpoints to connect to Outposts buckets so that you can perform actions within your virtual private cloud (VPC). For more information, see  Accessing S3 on Outposts using VPC only access points. This action lists endpoints associated with the Outposts.   Related actions include:    CreateEndpoint     DeleteEndpoint

    Args:
        next_token(str, optional): The next endpoint requested in the list. Defaults to None.
        max_results(int, optional): The max number of endpoints that can be returned on the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3outpost_endpoint.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3outpost_endpoint.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3outposts",
        operation="list_endpoints",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(
    hub,
    ctx,
    job_id: str,
    thing_name: str,
    force: bool = None,
    expected_version: int = None,
    status_details: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Cancels the execution of a job for a given thing.

    Args:
        job_id(str): The ID of the job to be canceled.
        thing_name(str): The name of the thing whose execution of the job will be canceled.
        force(bool, optional): (Optional) If true the job execution will be canceled if it has status IN_PROGRESS or QUEUED, otherwise the job execution will be canceled only if it has status QUEUED. If you attempt to cancel a job execution that is IN_PROGRESS, and you do not set force to true, then an InvalidStateTransitionException will be thrown. The default is false. Canceling a job execution which is "IN_PROGRESS", will cause the device to be unable to update the job execution status. Use caution and ensure that the device is able to recover to a valid state. Defaults to None.
        expected_version(int, optional): (Optional) The expected current version of the job execution. Each time you update the job execution, its version is incremented. If the version of the job execution stored in Jobs does not match, the update is rejected with a VersionMismatch error, and an ErrorResponse that contains the current job execution status data is returned. (This makes it unnecessary to perform a separate DescribeJobExecution request in order to obtain the job execution status data.). Defaults to None.
        status_details(Dict, optional): A collection of name/value pairs that describe the status of the job execution. If not specified, the statusDetails are unchanged. You can specify at most 10 name/value pairs. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.execution.init.cancel(
                ctx, job_id=value, thing_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.execution.init.cancel job_id=value, thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="cancel_job_execution",
        op_kwargs={
            "jobId": job_id,
            "thingName": thing_name,
            "force": force,
            "expectedVersion": expected_version,
            "statusDetails": status_details,
        },
    )


async def delete(
    hub,
    ctx,
    job_id: str,
    thing_name: str,
    execution_number: int,
    force: bool = None,
    namespace_id: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Deletes a job execution.

    Args:
        job_id(str): The ID of the job whose execution on a particular device will be deleted.
        thing_name(str): The name of the thing whose job execution will be deleted.
        execution_number(int): The ID of the job execution to be deleted. The executionNumber refers to the execution of a particular job on a particular device. Note that once a job execution is deleted, the executionNumber may be reused by IoT, so be sure you get and use the correct value here.
        force(bool, optional): (Optional) When true, you can delete a job execution which is "IN_PROGRESS". Otherwise, you can only delete a job execution which is in a terminal state ("SUCCEEDED", "FAILED", "REJECTED", "REMOVED" or "CANCELED") or an exception will occur. The default is false.  Deleting a job execution which is "IN_PROGRESS", will cause the device to be unable to access job information or update the job execution status. Use caution and ensure that the device is able to recover to a valid state. . Defaults to None.
        namespace_id(str, optional): The namespace used to indicate that a job is a customer-managed job. When you specify a value for this parameter, AWS IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.  $aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/   The namespaceId feature is in public preview. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.execution.init.delete(
                ctx, job_id=value, thing_name=value, execution_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.execution.init.delete job_id=value, thing_name=value, execution_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_job_execution",
        op_kwargs={
            "jobId": job_id,
            "thingName": thing_name,
            "executionNumber": execution_number,
            "force": force,
            "namespaceId": namespace_id,
        },
    )


async def describe(
    hub, ctx, job_id: str, thing_name: str, execution_number: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a job execution.

    Args:
        job_id(str): The unique identifier you assigned to this job when it was created.
        thing_name(str): The name of the thing on which the job execution is running.
        execution_number(int, optional): A string (consisting of the digits "0" through "9" which is used to specify a particular job execution on a particular device. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.execution.init.describe(
                ctx, job_id=value, thing_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.execution.init.describe job_id=value, thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_job_execution",
        op_kwargs={
            "jobId": job_id,
            "thingName": thing_name,
            "executionNumber": execution_number,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete a parameter from the system.

    Args:
        name(str): The name of the parameter to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.parameter.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.parameter.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ssm", operation="delete_parameter", op_kwargs={"Name": name}
    )


async def delete_multiple(hub, ctx, names: List) -> Dict:
    r"""
    **Autogenerated function**

    Delete a list of parameters.

    Args:
        names(List): The names of the parameters to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.parameter.init.delete_multiple(ctx, names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.parameter.init.delete_multiple names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="delete_parameters",
        op_kwargs={"Names": names},
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    parameter_filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Get information about a parameter. Request results are returned on a best-effort basis. If you specify MaxResults in the request, the response includes information up to the limit specified. The number of items returned, however, can be between zero and the value of MaxResults. If the service reaches an internal limit while processing the results, it stops the operation and returns the matching values up to that point and a NextToken. You can specify the NextToken in a subsequent call to get the next set of results.

    Args:
        filters(List, optional): This data type is deprecated. Instead, use ParameterFilters. Defaults to None.
        parameter_filters(List, optional): Filters to limit the request results. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.parameter.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.parameter.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_parameters",
        op_kwargs={
            "Filters": filters,
            "ParameterFilters": parameter_filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def get(hub, ctx, name: str, with_decryption: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Get information about a parameter by using the parameter name. Don't confuse this API operation with the GetParameters API operation.

    Args:
        name(str): The name of the parameter you want to query.
        with_decryption(bool, optional): Return decrypted values for secure string parameters. This flag is ignored for String and StringList parameter types. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.parameter.init.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.parameter.init.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_parameter",
        op_kwargs={"Name": name, "WithDecryption": with_decryption},
    )


async def get_all(hub, ctx, names: List, with_decryption: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Get details of a parameter. Don't confuse this API operation with the GetParameter API operation.

    Args:
        names(List): Names of the parameters for which you want to query information.
        with_decryption(bool, optional): Return decrypted secure string value. Return decrypted values for secure string parameters. This flag is ignored for String and StringList parameter types. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.parameter.init.get_all(ctx, names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.parameter.init.get_all names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_parameters",
        op_kwargs={"Names": names, "WithDecryption": with_decryption},
    )


async def put(
    hub,
    ctx,
    name: str,
    value: str,
    description: str = None,
    type_: str = None,
    key_id: str = None,
    overwrite: bool = None,
    allowed_pattern: str = None,
    tags: List = None,
    tier: str = None,
    policies: str = None,
    data_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Add a parameter to the system.

    Args:
        name(str): The fully qualified name of the parameter that you want to add to the system. The fully qualified name includes the complete hierarchy of the parameter path and name. For parameters in a hierarchy, you must include a leading forward slash character (/) when you create or reference a parameter. For example: /Dev/DBServer/MySQL/db-string13  Naming Constraints:   Parameter names are case sensitive.   A parameter name must be unique within an Region   A parameter name can't be prefixed with "aws" or "ssm" (case-insensitive).   Parameter names can include only the following symbols and letters: a-zA-Z0-9_.-  In addition, the slash character ( / ) is used to delineate hierarchies in parameter names. For example: /Dev/Production/East/Project-ABC/MyParameter    A parameter name can't include spaces.   Parameter hierarchies are limited to a maximum depth of fifteen levels.   For additional information about valid values for parameter names, see Creating Systems Manager parameters in the Amazon Web Services Systems Manager User Guide.  The maximum length constraint listed below includes capacity for additional system attributes that aren't part of the name. The maximum length for a parameter name, including the full length of the parameter ARN, is 1011 characters. For example, the length of the following parameter name is 65 characters, not 20 characters:  arn:aws:ssm:us-east-2:111122223333:parameter/ExampleParameterName  .
        description(str, optional): Information about the parameter that you want to add to the system. Optional but recommended.  Don't enter personally identifiable information in this field. . Defaults to None.
        value(str): The parameter value that you want to add to the system. Standard parameters have a value limit of 4 KB. Advanced parameters have a value limit of 8 KB.  Parameters can't be referenced or nested in the values of other parameters. You can't include {{}} or {{ssm:parameter-name}} in a parameter value. .
        type_(str, optional): The type of parameter that you want to add to the system.   SecureString isn't currently supported for CloudFormation templates.  Items in a StringList must be separated by a comma (,). You can't use other punctuation or special character to escape items in the list. If you have a parameter value that requires a comma, then use the String data type.  Specifying a parameter type isn't required when updating a parameter. You must specify a parameter type when creating a parameter. . Defaults to None.
        key_id(str, optional): The Key Management Service (KMS) ID that you want to use to encrypt a parameter. Either the default KMS key automatically assigned to your account or a custom key. Required for parameters that use the SecureString data type. If you don't specify a key ID, the system uses the default key associated with your account.   To use your default KMS key, choose the SecureString data type, and do not specify the Key ID when you create the parameter. The system automatically populates Key ID with your default KMS key.   To use a custom KMS key, choose the SecureString data type with the Key ID parameter.  . Defaults to None.
        overwrite(bool, optional): Overwrite an existing parameter. The default value is false. Defaults to None.
        allowed_pattern(str, optional): A regular expression used to validate the parameter value. For example, for String types with values restricted to numbers, you can specify the following: AllowedPattern=^\d+$ . Defaults to None.
        tags(List, optional): Optional metadata that you assign to a resource. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For example, you might want to tag a Systems Manager parameter to identify the type of resource to which it applies, the environment, or the type of configuration data referenced by the parameter. In this case, you could specify the following key-value pairs:    Key=Resource,Value=S3bucket     Key=OS,Value=Windows     Key=ParameterType,Value=LicenseKey     To add tags to an existing Systems Manager parameter, use the AddTagsToResource operation. . Defaults to None.
        tier(str, optional): The parameter tier to assign to a parameter. Parameter Store offers a standard tier and an advanced tier for parameters. Standard parameters have a content size limit of 4 KB and can't be configured to use parameter policies. You can create a maximum of 10,000 standard parameters for each Region in an account. Standard parameters are offered at no additional cost.  Advanced parameters have a content size limit of 8 KB and can be configured to use parameter policies. You can create a maximum of 100,000 advanced parameters for each Region in an account. Advanced parameters incur a charge. For more information, see Standard and advanced parameter tiers in the Amazon Web Services Systems Manager User Guide. You can change a standard parameter to an advanced parameter any time. But you can't revert an advanced parameter to a standard parameter. Reverting an advanced parameter to a standard parameter would result in data loss because the system would truncate the size of the parameter from 8 KB to 4 KB. Reverting would also remove any policies attached to the parameter. Lastly, advanced parameters use a different form of encryption than standard parameters.  If you no longer need an advanced parameter, or if you no longer want to incur charges for an advanced parameter, you must delete it and recreate it as a new standard parameter.   Using the Default Tier Configuration  In PutParameter requests, you can specify the tier to create the parameter in. Whenever you specify a tier in the request, Parameter Store creates or updates the parameter according to that request. However, if you don't specify a tier in a request, Parameter Store assigns the tier based on the current Parameter Store default tier configuration. The default tier when you begin using Parameter Store is the standard-parameter tier. If you use the advanced-parameter tier, you can specify one of the following as the default:    Advanced: With this option, Parameter Store evaluates all requests as advanced parameters.     Intelligent-Tiering: With this option, Parameter Store evaluates each request to determine if the parameter is standard or advanced.  If the request doesn't include any options that require an advanced parameter, the parameter is created in the standard-parameter tier. If one or more options requiring an advanced parameter are included in the request, Parameter Store create a parameter in the advanced-parameter tier. This approach helps control your parameter-related costs by always creating standard parameters unless an advanced parameter is necessary.    Options that require an advanced parameter include the following:   The content size of the parameter is more than 4 KB.   The parameter uses a parameter policy.   More than 10,000 parameters already exist in your account in the current Region.   For more information about configuring the default tier option, see Specifying a default parameter tier in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        policies(str, optional): One or more policies to apply to a parameter. This operation takes a JSON array. Parameter Store, a capability of Amazon Web Services Systems Manager supports the following policy types: Expiration: This policy deletes the parameter after it expires. When you create the policy, you specify the expiration date. You can update the expiration date and time by updating the policy. Updating the parameter doesn't affect the expiration date and time. When the expiration time is reached, Parameter Store deletes the parameter. ExpirationNotification: This policy triggers an event in Amazon CloudWatch Events that notifies you about the expiration. By using this policy, you can receive notification before or after the expiration time is reached, in units of days or hours. NoChangeNotification: This policy triggers a CloudWatch Events event if a parameter hasn't been modified for a specified period of time. This policy type is useful when, for example, a secret needs to be changed within a period of time, but it hasn't been changed. All existing policies are preserved until you send new policies or an empty policy. For more information about parameter policies, see Assigning parameter policies. . Defaults to None.
        data_type(str, optional): The data type for a String parameter. Supported data types include plain text and Amazon Machine Image (AMI) IDs.  The following data type values are supported.     text     aws:ec2:image    When you create a String parameter and specify aws:ec2:image, Amazon Web Services Systems Manager validates the parameter value is in the required format, such as ami-12345abcdeEXAMPLE, and that the specified AMI is available in your account. For more information, see Native parameter support for Amazon Machine Image (AMI) IDs in the Amazon Web Services Systems Manager User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.parameter.init.put(ctx, name=value, value=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.parameter.init.put name=value, value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="put_parameter",
        op_kwargs={
            "Name": name,
            "Description": description,
            "Value": value,
            "Type": type_,
            "KeyId": key_id,
            "Overwrite": overwrite,
            "AllowedPattern": allowed_pattern,
            "Tags": tags,
            "Tier": tier,
            "Policies": policies,
            "DataType": data_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    api_id: str,
    route_id: str,
    route_response_key: str,
    model_selection_expression: str = None,
    response_models: Dict = None,
    response_parameters: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a RouteResponse for a Route.

    Args:
        api_id(str): The API identifier.
        model_selection_expression(str, optional): The model selection expression for the route response. Supported only for WebSocket APIs. Defaults to None.
        response_models(Dict, optional): The response models for the route response. Defaults to None.
        response_parameters(Dict, optional): The route response parameters. Defaults to None.
        route_id(str): The route ID.
        route_response_key(str): The route response key.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.route.response.create(
                ctx, api_id=value, route_id=value, route_response_key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.route.response.create api_id=value, route_id=value, route_response_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="create_route_response",
        op_kwargs={
            "ApiId": api_id,
            "ModelSelectionExpression": model_selection_expression,
            "ResponseModels": response_models,
            "ResponseParameters": response_parameters,
            "RouteId": route_id,
            "RouteResponseKey": route_response_key,
        },
    )


async def delete(hub, ctx, api_id: str, route_id: str, route_response_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a RouteResponse.

    Args:
        api_id(str): The API identifier.
        route_id(str): The route ID.
        route_response_id(str): The route response ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.route.response.delete(
                ctx, api_id=value, route_id=value, route_response_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.route.response.delete api_id=value, route_id=value, route_response_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_route_response",
        op_kwargs={
            "ApiId": api_id,
            "RouteId": route_id,
            "RouteResponseId": route_response_id,
        },
    )


async def get(hub, ctx, api_id: str, route_id: str, route_response_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a RouteResponse.

    Args:
        api_id(str): The API identifier.
        route_id(str): The route ID.
        route_response_id(str): The route response ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.route.response.get(
                ctx, api_id=value, route_id=value, route_response_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.route.response.get api_id=value, route_id=value, route_response_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_route_response",
        op_kwargs={
            "ApiId": api_id,
            "RouteId": route_id,
            "RouteResponseId": route_response_id,
        },
    )


async def get_all(
    hub,
    ctx,
    api_id: str,
    route_id: str,
    max_results: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the RouteResponses for a Route.

    Args:
        api_id(str): The API identifier.
        max_results(str, optional): The maximum number of elements to be returned for this resource. Defaults to None.
        next_token(str, optional): The next page of elements from this collection. Not valid for the last element of the collection. Defaults to None.
        route_id(str): The route ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.route.response.get_all(
                ctx, api_id=value, route_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.route.response.get_all api_id=value, route_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_route_responses",
        op_kwargs={
            "ApiId": api_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "RouteId": route_id,
        },
    )


async def update(
    hub,
    ctx,
    api_id: str,
    route_id: str,
    route_response_id: str,
    model_selection_expression: str = None,
    response_models: Dict = None,
    response_parameters: Dict = None,
    route_response_key: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a RouteResponse.

    Args:
        api_id(str): The API identifier.
        model_selection_expression(str, optional): The model selection expression for the route response. Supported only for WebSocket APIs. Defaults to None.
        response_models(Dict, optional): The response models for the route response. Defaults to None.
        response_parameters(Dict, optional): The route response parameters. Defaults to None.
        route_id(str): The route ID.
        route_response_id(str): The route response ID.
        route_response_key(str, optional): The route response key. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.route.response.update(
                ctx, api_id=value, route_id=value, route_response_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.route.response.update api_id=value, route_id=value, route_response_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="update_route_response",
        op_kwargs={
            "ApiId": api_id,
            "ModelSelectionExpression": model_selection_expression,
            "ResponseModels": response_models,
            "ResponseParameters": response_parameters,
            "RouteId": route_id,
            "RouteResponseId": route_response_id,
            "RouteResponseKey": route_response_key,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def move(hub, ctx, public_ip: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Moves an Elastic IP address from the EC2-Classic platform to the EC2-VPC platform. The Elastic IP address must be allocated to your account for more than 24 hours, and it must not be associated with an instance. After the Elastic IP address is moved, it is no longer available for use in the EC2-Classic platform, unless you move it back using the RestoreAddressToClassic request. You cannot move an Elastic IP address that was originally allocated for use in the EC2-VPC platform to the EC2-Classic platform.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        public_ip(str): The Elastic IP address.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.address.to.vpc.move(ctx, public_ip=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.address.to.vpc.move public_ip=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="move_address_to_vpc",
        op_kwargs={"DryRun": dry_run, "PublicIp": public_ip},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    thing_name: str = None,
    security_profile_name: str = None,
    behavior_criteria_type: str = None,
    list_suppressed_alerts: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the active violations for a given Device Defender security profile.

    Args:
        thing_name(str, optional): The name of the thing whose active violations are listed. Defaults to None.
        security_profile_name(str, optional): The name of the Device Defender security profile for which violations are listed. Defaults to None.
        behavior_criteria_type(str, optional):  The criteria for a behavior. . Defaults to None.
        list_suppressed_alerts(bool, optional):  A list of all suppressed alerts. . Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.active_violation.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.active_violation.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_active_violations",
        op_kwargs={
            "thingName": thing_name,
            "securityProfileName": security_profile_name,
            "behaviorCriteriaType": behavior_criteria_type,
            "listSuppressedAlerts": list_suppressed_alerts,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub,
    ctx,
    image_version_arn: str,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of image build versions.

    Args:
        image_version_arn(str): The Amazon Resource Name (ARN) of the image whose build versions you want to retrieve.
        filters(List, optional): The filters. Defaults to None.
        max_results(int, optional): The maximum items to return in a request. Defaults to None.
        next_token(str, optional): A token to specify where to start paginating. This is the NextToken from a previously truncated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.build_version.list_all(
                ctx, image_version_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.build_version.list_all image_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="list_image_build_versions",
        op_kwargs={
            "imageVersionArn": image_version_arn,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    data_type: str,
    data_source: str,
    default_value: str,
    description: str = None,
    variable_type: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a variable.

    Args:
        name(str): The name of the variable.
        data_type(str): The data type.
        data_source(str): The source of the data.
        default_value(str): The default value for the variable when no value is received.
        description(str, optional): The description. Defaults to None.
        variable_type(str, optional): The variable type. For more information see Variable types.  Valid Values: AUTH_CODE | AVS | BILLING_ADDRESS_L1 | BILLING_ADDRESS_L2 | BILLING_CITY | BILLING_COUNTRY | BILLING_NAME | BILLING_PHONE | BILLING_STATE | BILLING_ZIP | CARD_BIN | CATEGORICAL | CURRENCY_CODE | EMAIL_ADDRESS | FINGERPRINT | FRAUD_LABEL | FREE_FORM_TEXT | IP_ADDRESS | NUMERIC | ORDER_ID | PAYMENT_TYPE | PHONE_NUMBER | PRICE | PRODUCT_CATEGORY | SHIPPING_ADDRESS_L1 | SHIPPING_ADDRESS_L2 | SHIPPING_CITY | SHIPPING_COUNTRY | SHIPPING_NAME | SHIPPING_PHONE | SHIPPING_STATE | SHIPPING_ZIP | USERAGENT . Defaults to None.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.variable.create(
                ctx, name=value, data_type=value, data_source=value, default_value=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.variable.create name=value, data_type=value, data_source=value, default_value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="create_variable",
        op_kwargs={
            "name": name,
            "dataType": data_type,
            "dataSource": data_source,
            "defaultValue": default_value,
            "description": description,
            "variableType": variable_type,
            "tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a variable. You can't delete variables that are included in an event type in Amazon Fraud Detector. Amazon Fraud Detector automatically deletes model output variables and SageMaker model output variables when you delete the model. You can't delete these variables manually. When you delete a variable, Amazon Fraud Detector permanently deletes that variable and the data is no longer stored in Amazon Fraud Detector.

    Args:
        name(str): The name of the variable to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.variable.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.variable.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_variable",
        op_kwargs={"name": name},
    )


async def get_all(
    hub, ctx, name: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets all of the variables or the specific variable. This is a paginated API. Providing null maxSizePerPage results in retrieving maximum of 100 records per page. If you provide maxSizePerPage the value must be between 50 and 100. To get the next page result, a provide a pagination token from GetVariablesResult as part of your request. Null pagination token fetches the records from the beginning.

    Args:
        name(str, optional): The name of the variable. . Defaults to None.
        next_token(str, optional): The next page token of the get variable request. . Defaults to None.
        max_results(int, optional): The max size per page determined for the get variable request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.variable.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.variable.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_variables",
        op_kwargs={"name": name, "nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    name: str,
    default_value: str = None,
    description: str = None,
    variable_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a variable.

    Args:
        name(str): The name of the variable.
        default_value(str, optional): The new default value of the variable. Defaults to None.
        description(str, optional): The new description. Defaults to None.
        variable_type(str, optional): The variable type. For more information see Variable types. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.variable.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.variable.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="update_variable",
        op_kwargs={
            "name": name,
            "defaultValue": default_value,
            "description": description,
            "variableType": variable_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    instance_id: str,
    filters: Dict,
    current_metrics: List,
    groupings: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the real-time metric data from the specified Amazon Connect instance. For a description of each metric, see Real-time Metrics Definitions in the Amazon Connect Administrator Guide.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        filters(Dict): The queues, up to 100, or channels, to use to filter the metrics returned. Metric data is retrieved only for the resources associated with the queues or channels included in the filter. You can include both queue IDs and queue ARNs in the same request. VOICE, CHAT, and TASK channels are supported.
        groupings(List, optional): The grouping applied to the metrics returned. For example, when grouped by QUEUE, the metrics returned apply to each queue rather than aggregated for all queues. If you group by CHANNEL, you should include a Channels filter. VOICE, CHAT, and TASK channels are supported. If no Grouping is included in the request, a summary of metrics is returned. Defaults to None.
        current_metrics(List): The metrics to retrieve. Specify the name and unit for each metric. The following metrics are available. For a description of all the metrics, see Real-time Metrics Definitions in the Amazon Connect Administrator Guide.  AGENTS_AFTER_CONTACT_WORK  Unit: COUNT Name in real-time metrics report: ACW   AGENTS_AVAILABLE  Unit: COUNT Name in real-time metrics report: Available   AGENTS_ERROR  Unit: COUNT Name in real-time metrics report: Error   AGENTS_NON_PRODUCTIVE  Unit: COUNT Name in real-time metrics report: NPT (Non-Productive Time)   AGENTS_ON_CALL  Unit: COUNT Name in real-time metrics report: On contact   AGENTS_ON_CONTACT  Unit: COUNT Name in real-time metrics report: On contact   AGENTS_ONLINE  Unit: COUNT Name in real-time metrics report: Online   AGENTS_STAFFED  Unit: COUNT Name in real-time metrics report: Staffed   CONTACTS_IN_QUEUE  Unit: COUNT Name in real-time metrics report: In queue   CONTACTS_SCHEDULED  Unit: COUNT Name in real-time metrics report: Scheduled   OLDEST_CONTACT_AGE  Unit: SECONDS When you use groupings, Unit says SECONDS but the Value is returned in MILLISECONDS. For example, if you get a response like this:  { "Metric": { "Name": "OLDEST_CONTACT_AGE", "Unit": "SECONDS" }, "Value": 24113.0 } The actual OLDEST_CONTACT_AGE is 24 seconds. Name in real-time metrics report: Oldest   SLOTS_ACTIVE  Unit: COUNT Name in real-time metrics report: Active   SLOTS_AVAILABLE  Unit: COUNT Name in real-time metrics report: Availability   .
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. The token expires after 5 minutes from the time it is created. Subsequent requests that use the token must use the same request parameters as the request that generated the token. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.current_metric_data.get(
                ctx, instance_id=value, filters=value, current_metrics=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.current_metric_data.get instance_id=value, filters=value, current_metrics=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="get_current_metric_data",
        op_kwargs={
            "InstanceId": instance_id,
            "Filters": filters,
            "Groupings": groupings,
            "CurrentMetrics": current_metrics,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def activate(
    hub,
    ctx,
    pipeline_id: str,
    parameter_values: List = None,
    start_timestamp: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Validates the specified pipeline and starts processing pipeline tasks. If the pipeline does not pass validation, activation fails. If you need to pause the pipeline to investigate an issue with a component, such as a data source or script, call DeactivatePipeline. To activate a finished pipeline, modify the end date for the pipeline and then activate it.

    Args:
        pipeline_id(str): The ID of the pipeline.
        parameter_values(List, optional): A list of parameter values to pass to the pipeline at activation. Defaults to None.
        start_timestamp(str, optional): The date and time to resume the pipeline. By default, the pipeline resumes from the last completed execution. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.pipeline.init.activate(ctx, pipeline_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.pipeline.init.activate pipeline_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="activate_pipeline",
        op_kwargs={
            "pipelineId": pipeline_id,
            "parameterValues": parameter_values,
            "startTimestamp": start_timestamp,
        },
    )


async def create(
    hub, ctx, name: str, unique_id: str, description: str = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new, empty pipeline. Use PutPipelineDefinition to populate the pipeline.

    Args:
        name(str): The name for the pipeline. You can use the same name for multiple pipelines associated with your AWS account, because AWS Data Pipeline assigns each pipeline a unique pipeline identifier.
        unique_id(str): A unique identifier. This identifier is not the same as the pipeline identifier assigned by AWS Data Pipeline. You are responsible for defining the format and ensuring the uniqueness of this identifier. You use this parameter to ensure idempotency during repeated calls to CreatePipeline. For example, if the first call to CreatePipeline does not succeed, you can pass in the same unique identifier and pipeline name combination on a subsequent call to CreatePipeline. CreatePipeline ensures that if a pipeline already exists with the same name and unique identifier, a new pipeline is not created. Instead, you'll receive the pipeline identifier from the previous attempt. The uniqueness of the name and unique identifier combination is scoped to the AWS account or IAM user credentials.
        description(str, optional): The description for the pipeline. Defaults to None.
        tags(List, optional): A list of tags to associate with the pipeline at creation. Tags let you control access to pipelines. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.pipeline.init.create(
                ctx, name=value, unique_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.pipeline.init.create name=value, unique_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="create_pipeline",
        op_kwargs={
            "name": name,
            "uniqueId": unique_id,
            "description": description,
            "tags": tags,
        },
    )


async def deactivate(hub, ctx, pipeline_id: str, cancel_active: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deactivates the specified running pipeline. The pipeline is set to the DEACTIVATING state until the deactivation process completes. To resume a deactivated pipeline, use ActivatePipeline. By default, the pipeline resumes from the last completed execution. Optionally, you can specify the date and time to resume the pipeline.

    Args:
        pipeline_id(str): The ID of the pipeline.
        cancel_active(bool, optional): Indicates whether to cancel any running objects. The default is true, which sets the state of any running objects to CANCELED. If this value is false, the pipeline is deactivated after all running objects finish. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.pipeline.init.deactivate(ctx, pipeline_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.pipeline.init.deactivate pipeline_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="deactivate_pipeline",
        op_kwargs={"pipelineId": pipeline_id, "cancelActive": cancel_active},
    )


async def delete(hub, ctx, pipeline_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a pipeline, its pipeline definition, and its run history. AWS Data Pipeline attempts to cancel instances associated with the pipeline that are currently being processed by task runners. Deleting a pipeline cannot be undone. You cannot query or restore a deleted pipeline. To temporarily pause a pipeline instead of deleting it, call SetStatus with the status set to PAUSE on individual components. Components that are paused by SetStatus can be resumed.

    Args:
        pipeline_id(str): The ID of the pipeline.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.pipeline.init.delete(ctx, pipeline_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.pipeline.init.delete pipeline_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="delete_pipeline",
        op_kwargs={"pipelineId": pipeline_id},
    )


async def describe_all(hub, ctx, pipeline_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves metadata about one or more pipelines. The information retrieved includes the name of the pipeline, the pipeline identifier, its current state, and the user account that owns the pipeline. Using account credentials, you can retrieve metadata about pipelines that you or your IAM users have created. If you are using an IAM user account, you can retrieve metadata about only those pipelines for which you have read permissions. To retrieve the full pipeline definition instead of metadata about the pipeline, call GetPipelineDefinition.

    Args:
        pipeline_ids(List): The IDs of the pipelines to describe. You can pass as many as 25 identifiers in a single call. To obtain pipeline IDs, call ListPipelines.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.pipeline.init.describe_all(ctx, pipeline_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.pipeline.init.describe_all pipeline_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="describe_pipelines",
        op_kwargs={"pipelineIds": pipeline_ids},
    )


async def list_all(hub, ctx, marker: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the pipeline identifiers for all active pipelines that you have permission to access.

    Args:
        marker(str, optional): The starting point for the results to be returned. For the first call, this value should be empty. As long as there are more results, continue to call ListPipelines with the marker value from the previous call to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.pipeline.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.pipeline.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="list_pipelines",
        op_kwargs={"marker": marker},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def describe(
    hub, ctx, progress_update_stream: str, migration_task_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of all attributes associated with a specific migration task.

    Args:
        progress_update_stream(str): The name of the ProgressUpdateStream. .
        migration_task_name(str): The identifier given to the MigrationTask. Do not store personal data in this field. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.migration_task.init.describe(ctx, progress_update_stream=value, migration_task_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.migration_task.init.describe progress_update_stream=value, migration_task_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="describe_migration_task",
        op_kwargs={
            "ProgressUpdateStream": progress_update_stream,
            "MigrationTaskName": migration_task_name,
        },
    )


async def import_(
    hub,
    ctx,
    progress_update_stream: str,
    migration_task_name: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers a new migration task which represents a server, database, etc., being migrated to AWS by a migration tool. This API is a prerequisite to calling the NotifyMigrationTaskState API as the migration tool must first register the migration task with Migration Hub.

    Args:
        progress_update_stream(str): The name of the ProgressUpdateStream. >.
        migration_task_name(str): Unique identifier that references the migration task. Do not store personal data in this field. .
        dry_run(bool, optional): Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.migration_task.init.import(ctx, progress_update_stream=value, migration_task_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.migration_task.init.import progress_update_stream=value, migration_task_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="import_migration_task",
        op_kwargs={
            "ProgressUpdateStream": progress_update_stream,
            "MigrationTaskName": migration_task_name,
            "DryRun": dry_run,
        },
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, resource_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all, or filtered by resource name, migration tasks associated with the user account making this call. This API has the following traits:   Can show a summary list of the most recent migration tasks.   Can show a summary list of migration tasks associated with a given discovered resource.   Lists migration tasks in a paginated interface.

    Args:
        next_token(str, optional): If a NextToken was returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in NextToken. Defaults to None.
        max_results(int, optional): Value to specify how many results are returned per page. Defaults to None.
        resource_name(str, optional): Filter migration tasks by discovered resource name. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.migration_task.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.migration_task.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="list_migration_tasks",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "ResourceName": resource_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, id_: str, thing_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates a wireless device with a thing.

    Args:
        id_(str): The ID of the resource to update.
        thing_arn(str): The ARN of the thing to associate with the wireless device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.device.with_thing.associate(
                ctx, id_=value, thing_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.device.with_thing.associate id_=value, thing_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="associate_wireless_device_with_thing",
        op_kwargs={"Id": id_, "ThingArn": thing_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(
    hub,
    ctx,
    transit_gateway_multicast_domain_id: str = None,
    group_ip_address: str = None,
    network_interface_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters the specified members (network interfaces) from the transit gateway multicast group.

    Args:
        transit_gateway_multicast_domain_id(str, optional): The ID of the transit gateway multicast domain. Defaults to None.
        group_ip_address(str, optional): The IP address assigned to the transit gateway multicast group. Defaults to None.
        network_interface_ids(List, optional): The IDs of the group members' network interfaces. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.group.member.deregister(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.group.member.deregister
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="deregister_transit_gateway_multicast_group_members",
        op_kwargs={
            "TransitGatewayMulticastDomainId": transit_gateway_multicast_domain_id,
            "GroupIpAddress": group_ip_address,
            "NetworkInterfaceIds": network_interface_ids,
            "DryRun": dry_run,
        },
    )


async def register(
    hub,
    ctx,
    transit_gateway_multicast_domain_id: str = None,
    group_ip_address: str = None,
    network_interface_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers members (network interfaces) with the transit gateway multicast group. A member is a network interface associated with a supported EC2 instance that receives multicast traffic. For information about supported instances, see Multicast Consideration in Amazon VPC Transit Gateways. After you add the members, use SearchTransitGatewayMulticastGroups to verify that the members were added to the transit gateway multicast group.

    Args:
        transit_gateway_multicast_domain_id(str, optional): The ID of the transit gateway multicast domain. Defaults to None.
        group_ip_address(str, optional): The IP address assigned to the transit gateway multicast group. Defaults to None.
        network_interface_ids(List, optional): The group members' network interface IDs to register with the transit gateway multicast group. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.group.member.register(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.group.member.register
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="register_transit_gateway_multicast_group_members",
        op_kwargs={
            "TransitGatewayMulticastDomainId": transit_gateway_multicast_domain_id,
            "GroupIpAddress": group_ip_address,
            "NetworkInterfaceIds": network_interface_ids,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(
    hub, ctx, resource_name: str, tags: List, resource_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more tags to the specified Amazon Lightsail resource. Each resource can have a maximum of 50 tags. Each tag consists of a key and an optional value. Tag keys must be unique per resource. For more information about tags, see the Amazon Lightsail Developer Guide. The tag resource operation supports tag-based access control via request tags and resource tags applied to the resource identified by resource name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        resource_name(str): The name of the resource to which you are adding tags.
        resource_arn(str, optional): The Amazon Resource Name (ARN) of the resource to which you want to add a tag. Defaults to None.
        tags(List): The tag key and optional value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.resource.init.tag(
                ctx, resource_name=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.resource.init.tag resource_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="tag_resource",
        op_kwargs={
            "resourceName": resource_name,
            "resourceArn": resource_arn,
            "tags": tags,
        },
    )


async def untag(
    hub, ctx, resource_name: str, tag_keys: List, resource_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified set of tag keys and their values from the specified Amazon Lightsail resource. The untag resource operation supports tag-based access control via request tags and resource tags applied to the resource identified by resource name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        resource_name(str): The name of the resource from which you are removing a tag.
        resource_arn(str, optional): The Amazon Resource Name (ARN) of the resource from which you want to remove a tag. Defaults to None.
        tag_keys(List): The tag keys to delete from the specified resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.resource.init.untag(
                ctx, resource_name=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.resource.init.untag resource_name=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="untag_resource",
        op_kwargs={
            "resourceName": resource_name,
            "resourceArn": resource_arn,
            "tagKeys": tag_keys,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    predictor_name: str,
    forecast_horizon: int,
    input_data_config: Dict,
    featurization_config: Dict,
    algorithm_arn: str = None,
    forecast_types: List = None,
    perform_auto_ml: bool = None,
    auto_ml_override_strategy: str = None,
    perform_hpo: bool = None,
    training_parameters: Dict = None,
    evaluation_parameters: Dict = None,
    hpo_config: Dict = None,
    encryption_config: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Forecast predictor. In the request, provide a dataset group and either specify an algorithm or let Amazon Forecast choose an algorithm for you using AutoML. If you specify an algorithm, you also can override algorithm-specific hyperparameters. Amazon Forecast uses the algorithm to train a predictor using the latest version of the datasets in the specified dataset group. You can then generate a forecast using the CreateForecast operation.  To see the evaluation metrics, use the GetAccuracyMetrics operation.  You can specify a featurization configuration to fill and aggregate the data fields in the TARGET_TIME_SERIES dataset to improve model training. For more information, see FeaturizationConfig. For RELATED_TIME_SERIES datasets, CreatePredictor verifies that the DataFrequency specified when the dataset was created matches the ForecastFrequency. TARGET_TIME_SERIES datasets don't have this restriction. Amazon Forecast also verifies the delimiter and timestamp format. For more information, see howitworks-datasets-groups. By default, predictors are trained and evaluated at the 0.1 (P10), 0.5 (P50), and 0.9 (P90) quantiles. You can choose custom forecast types to train and evaluate your predictor by setting the ForecastTypes.   AutoML  If you want Amazon Forecast to evaluate each algorithm and choose the one that minimizes the objective function, set PerformAutoML to true. The objective function is defined as the mean of the weighted losses over the forecast types. By default, these are the p10, p50, and p90 quantile losses. For more information, see EvaluationResult. When AutoML is enabled, the following properties are disallowed:    AlgorithmArn     HPOConfig     PerformHPO     TrainingParameters    To get a list of all of your predictors, use the ListPredictors operation.  Before you can use the predictor to create a forecast, the Status of the predictor must be ACTIVE, signifying that training has completed. To get the status, use the DescribePredictor operation.

    Args:
        predictor_name(str): A name for the predictor.
        algorithm_arn(str, optional): The Amazon Resource Name (ARN) of the algorithm to use for model training. Required if PerformAutoML is not set to true.  Supported algorithms:     arn:aws:forecast:::algorithm/ARIMA     arn:aws:forecast:::algorithm/CNN-QR     arn:aws:forecast:::algorithm/Deep_AR_Plus     arn:aws:forecast:::algorithm/ETS     arn:aws:forecast:::algorithm/NPTS     arn:aws:forecast:::algorithm/Prophet   . Defaults to None.
        forecast_horizon(int): Specifies the number of time-steps that the model is trained to predict. The forecast horizon is also called the prediction length. For example, if you configure a dataset for daily data collection (using the DataFrequency parameter of the CreateDataset operation) and set the forecast horizon to 10, the model returns predictions for 10 days. The maximum forecast horizon is the lesser of 500 time-steps or 1/3 of the TARGET_TIME_SERIES dataset length.
        forecast_types(List, optional): Specifies the forecast types used to train a predictor. You can specify up to five forecast types. Forecast types can be quantiles from 0.01 to 0.99, by increments of 0.01 or higher. You can also specify the mean forecast with mean.  The default value is ["0.10", "0.50", "0.9"]. Defaults to None.
        perform_auto_ml(bool, optional): Whether to perform AutoML. When Amazon Forecast performs AutoML, it evaluates the algorithms it provides and chooses the best algorithm and configuration for your training dataset. The default value is false. In this case, you are required to specify an algorithm. Set PerformAutoML to true to have Amazon Forecast perform AutoML. This is a good option if you aren't sure which algorithm is suitable for your training data. In this case, PerformHPO must be false. Defaults to None.
        auto_ml_override_strategy(str, optional): Used to overide the default AutoML strategy, which is to optimize predictor accuracy. To apply an AutoML strategy that minimizes training time, use LatencyOptimized. This parameter is only valid for predictors trained using AutoML. Defaults to None.
        perform_hpo(bool, optional): Whether to perform hyperparameter optimization (HPO). HPO finds optimal hyperparameter values for your training data. The process of performing HPO is known as running a hyperparameter tuning job. The default value is false. In this case, Amazon Forecast uses default hyperparameter values from the chosen algorithm. To override the default values, set PerformHPO to true and, optionally, supply the HyperParameterTuningJobConfig object. The tuning job specifies a metric to optimize, which hyperparameters participate in tuning, and the valid range for each tunable hyperparameter. In this case, you are required to specify an algorithm and PerformAutoML must be false. The following algorithms support HPO:   DeepAR+   CNN-QR  . Defaults to None.
        training_parameters(Dict, optional): The hyperparameters to override for model training. The hyperparameters that you can override are listed in the individual algorithms. For the list of supported algorithms, see aws-forecast-choosing-recipes. Defaults to None.
        evaluation_parameters(Dict, optional): Used to override the default evaluation parameters of the specified algorithm. Amazon Forecast evaluates a predictor by splitting a dataset into training data and testing data. The evaluation parameters define how to perform the split and the number of iterations. Defaults to None.
        hpo_config(Dict, optional): Provides hyperparameter override values for the algorithm. If you don't provide this parameter, Amazon Forecast uses default values. The individual algorithms specify which hyperparameters support hyperparameter optimization (HPO). For more information, see aws-forecast-choosing-recipes. If you included the HPOConfig object, you must set PerformHPO to true. Defaults to None.
        input_data_config(Dict): Describes the dataset group that contains the data to use to train the predictor.
        featurization_config(Dict): The featurization configuration.
        encryption_config(Dict, optional): An AWS Key Management Service (KMS) key and the AWS Identity and Access Management (IAM) role that Amazon Forecast can assume to access the key. Defaults to None.
        tags(List, optional): The optional metadata that you apply to the predictor to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50.   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8.   Maximum value length - 256 Unicode characters in UTF-8.   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Forecast considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.predictor.init.create(
                ctx,
                predictor_name=value,
                forecast_horizon=value,
                input_data_config=value,
                featurization_config=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.predictor.init.create predictor_name=value, forecast_horizon=value, input_data_config=value, featurization_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="create_predictor",
        op_kwargs={
            "PredictorName": predictor_name,
            "AlgorithmArn": algorithm_arn,
            "ForecastHorizon": forecast_horizon,
            "ForecastTypes": forecast_types,
            "PerformAutoML": perform_auto_ml,
            "AutoMLOverrideStrategy": auto_ml_override_strategy,
            "PerformHPO": perform_hpo,
            "TrainingParameters": training_parameters,
            "EvaluationParameters": evaluation_parameters,
            "HPOConfig": hpo_config,
            "InputDataConfig": input_data_config,
            "FeaturizationConfig": featurization_config,
            "EncryptionConfig": encryption_config,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, predictor_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a predictor created using the CreatePredictor operation. You can delete only predictor that have a status of ACTIVE or CREATE_FAILED. To get the status, use the DescribePredictor operation.

    Args:
        predictor_arn(str): The Amazon Resource Name (ARN) of the predictor to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.predictor.init.delete(ctx, predictor_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.predictor.init.delete predictor_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="delete_predictor",
        op_kwargs={"PredictorArn": predictor_arn},
    )


async def describe(hub, ctx, predictor_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a predictor created using the CreatePredictor operation. In addition to listing the properties provided in the CreatePredictor request, this operation lists the following properties:    DatasetImportJobArns - The dataset import jobs used to import training data.    AutoMLAlgorithmArns - If AutoML is performed, the algorithms that were evaluated.    CreationTime     LastModificationTime     Status     Message - If an error occurred, information about the error.

    Args:
        predictor_arn(str): The Amazon Resource Name (ARN) of the predictor that you want information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.predictor.init.describe(ctx, predictor_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.predictor.init.describe predictor_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="describe_predictor",
        op_kwargs={"PredictorArn": predictor_arn},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of predictors created using the CreatePredictor operation. For each predictor, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). You can retrieve the complete set of properties by using the ARN with the DescribePredictor operation. You can filter the list using an array of Filter objects.

    Args:
        next_token(str, optional): If the result of the previous request was truncated, the response includes a NextToken. To retrieve the next set of results, use the token in the next request. Tokens expire after 24 hours. Defaults to None.
        max_results(int, optional): The number of items to return in the response. Defaults to None.
        filters(List, optional): An array of filters. For each filter, you provide a condition and a match statement. The condition is either IS or IS_NOT, which specifies whether to include or exclude the predictors that match the statement from the list, respectively. The match statement consists of a key and a value.  Filter properties     Condition - The condition to apply. Valid values are IS and IS_NOT. To include the predictors that match the statement, specify IS. To exclude matching predictors, specify IS_NOT.    Key - The name of the parameter to filter on. Valid values are DatasetGroupArn and Status.    Value - The value to match.   For example, to list all predictors whose status is ACTIVE, you would specify:  "Filters": [ { "Condition": "IS", "Key": "Status", "Value": "ACTIVE" } ] . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.predictor.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.predictor.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="list_predictors",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
        },
    )
